from setuptools import setup

from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(name='feather-api',
      version='1.0.0-rc.1',
      description='Python wrapper for Feather\'s API',
      long_description=long_description,
      long_description_content_type='text/markdown',
      url='http://github.com/Feather-Official/featherdbtools',
      author='Feather Technology Inc.',
      author_email='support@try-feather.com',
      packages=['featherapi'],
      install_requires=['setuptools', 'requests'],
      setup_requires=['setuptools'],
      zip_safe=False)


import os

import requests

class DataClient:

    BASE_URL = 'https://api.try-feather.com/v2'

    API_KEY = os.environ.get('FEATHER_API_KEY', None)

    def __init__(self, api_key=API_KEY):
        self.api_key = api_key

        session = requests.Session()
        session.headers.update({'x-api-key': api_key})

        self.session = session
    
    def get_equity_facts(self, symbol, start=None, end=None):
        path = f'/equity/facts/{symbol}/all'

        query_params = {}

        if start: query_params['start'] = start
        if end: query_params['end'] = end


        response = self.__get_url(path, query_params)
        data = response['data']
        return data

    def get_available_equity_facts(self, symbol):
        path = f'/equity/facts/{symbol}/available'
        response = self.__get_url(path)
        data = response['data']
        return data

    def __get_url(self, path, query_params={}):
        url = self.BASE_URL + path

        session = self.session

        response = session.get(url, params=query_params)
        return response.json()
